#
# See the file "LICENSE" for the full license governing this code.
#
# encoding: UTF-8
newproperty(:state) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  newvalues(:running, :stopped, :mounted)

  desc <<-EOD
    State of the database, either running, mounted or stopped.
  EOD

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('STATE')
  end

  on_modify do
    if ['stopped', :stopped].include? provider.state
      if resource.state == :mounted
        sql 'startup mount', :sid => instance
      elsif resource.state == :running
        sql 'startup', :sid => instance
      end
    elsif ['running', :running].include? provider.state
      if resource.state == :mounted
        sql 'shutdown immediate
             startup mount', :sid => instance, :failonsqlfail => false
      elsif resource.state == :stopped
        sql 'shutdown immediate', :sid => instance
      end
    elsif ['mounted', :mounted].include? provider.state
      if resource.state == :stopped
        sql 'shutdown immediate', :sid => instance, :failonsqlfail => false
      elsif resource.state == :running
        sql 'alter database open', :sid => instance
      end
    end
  end
end
