#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:max_failures) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  desc <<-EOD
    The maximum number of failures for the job before the job is marked broken.

    Here is an example on how to use this:

        ora_scheduler_job{ 'me.my_job@sid':
          ...
          max_failures => 5,
          ...
        }

    Puppet doesn't provide a default value.

  EOD
  
  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('MAX_FAILURES')
  end

  on_modify do
    if resource.max_failures == '' or resource.max_failures.nil?
      statement = "begin dbms_scheduler.set_attribute_null(name => '#{resource.owner}.#{resource.job_name}', attribute => 'MAX_FAILURES'); end;\n/\n"
    else
      statement = template('ora_config/ora_scheduler_job/modify_unquoted_attribute.sql.erb', binding)
    end
    sql statement, {:sid => resource.sid}
  end

end
