#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:max_run_duration) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  desc <<-EOD
    The maximum duration of the job specified in seconds.

    Here is an example on how to use this:

        ora_scheduler_job{ 'me.my_job@sid':
          ...
          max_run_duration => '10800',
          ...
        }

    Puppet doesn't provide a default value.

  EOD
  
  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('MAX_RUN_DURATION')
  end

  on_modify do
    if resource.max_run_duration == '' or resource.max_run_duration.nil?
      statement = "begin dbms_scheduler.set_attribute_null(name => '#{resource.owner}.#{resource.job_name}', attribute => 'MAX_RUN_DURATION'); end;\n/\n"
    else
      statement = template('ora_config/ora_scheduler_job/modify_interval_attribute.sql.erb', binding)
    end
    sql statement, {:sid => resource.sid}
  end

end
